 
*     PRETEP IS A PREPROCESSOR FOR ORTEP-II.  MACRO INSTRUCTIONS ARE EXP
*     FOLLOWS:
*     (1) READ PRETEP INSTRUCTIONS AND DECODE THEM;
*     (2) IF STRUCTURE DATA ARE NOT INPUT BY THE USER, READ THEM FROM AN
*         FILE CREATED BY RIETAN;
*     (3) MAKE AN INPUT FILE FOR ORTEP.
 
*     EXTERNAL FILES
*        INPUT FILE
*              UNIT 1: ORFFE FILE CREATED BY RIETAN.  WHEN AN ORFFE FILE
*                      SUPPLIED, YOU MUST INPUT INSTRUCTIONS 1-4.
*              UNIT 5: PRETEP FILE.
*        OUTPUT FILE
*              UNIT 2: TEMPORARY FILE STORING PARAMETERS IN PRETEP INSTR
*              UNIT 3: ORTEP FILE.
*              UNIT 6: PRINTER OUTPUT.
 
*     YOU MUST CONSULT THE FOLLOWING MANUALS TO LEARN ADC, ADR, ANR, AND
*     TECHNICAL TERMS ASSOCIATED WITH ORTEP-II:
 
*       C.K. JOHNSON: ORTEP, REPORT ORNL-3794, OAK RIDGE NATIONAL LABORA
*       TENNESSEE (1965).
*       C.K. JOHNSON: ORTEP-II, REPORT ORNL-5138, OAK RIDGE NATIONAL LAB
*       TENNESSEE (1976).
 
 
*     LISTS OF PRETEP INSTRUCTIONS
 
*      EACH LINE CONSISTS OF A SHELX-LIKE FOUR-CHARACTER LABEL PLUS ARGU
*      ONLY A 'CELL' INSTRUCTION CAN BE INPUT WITHOUT ANY ARGUMENT, AND
*      INSTRUCTION #4 HAVE NOT ANY LABEL.
 
*      YOU CAN INPUT THESE INSTRUCTIONS IN ANY ORDERS YOU LIKE.  YOU MAY
*      SOME OF THEM OR INPUT ONE INSTRUCTION REPEATEDLY.
 
*       1) TITL TITLE
*       2) LATT A B C ALPHA BETA GAMMA
*       3) SYMM XYZ
*       4) (SITE NAME) X Y Z B
*                   OR
*          (SITE NAME) X Y Z BETA11 BETA22 BETA33 BETA12 BETA13 BETA23
*       5) DMAX RADIUS
*       6) DIST R
*       7) ADDA ADC1 ADC2 .....
*       8) ABOX ANR1 ANR2 NCBOX ALIM BLIM CLIM
*       9) DELA ADC1 ADC2 .....
*      10) DBOX ANR1 ANR2 NCBOX ALIM BLIM CLIM
*      11) ROTA PHI1 PHI2 PHI3
*      12) SCAL FACTOR PREL X0 Y0
*      13) BALL NPLANE NLINE
*      14) CELL
*      15) PAIR RAD2 ADC1 ADC2 .....
*      16) BOND ANR1 ANR2 ANR3 ANR4 D1 D2 RAD1
*      17) LABL ADC XMOVE YMOVE HEIGHT
 
*     IF YOU WANT TO ADD FURTHER INSTRUCTIONS, PLEASE LET ME KNOW ABOUT
*     I CAN MODIFY THIS PROGRAM QUITE EASILY TO IMPLEMENT THEM.
 
*     IN THE DESCRIPTIONS THAT FOLLOW, FIGURES IN PARENTHESES SHOW CORRE
*     ING INSTRUCTIONS IN ORTEP-II, AND '==>' INSTRUCTION PLUS ITS ARGUM
*     DEFAULT VALUES ARE ADOPTED WHEN THE INSTRUCTION IS NOT INPUT AT AL
 
*     INSTRUCTION 1
*     INPUT A TITLE.
*     ==> TITL TITLE
*     TITLE: TITLE PRINTED IN THE OUTPUT (CHARACTER*72).
 
*     INSTRUCTION 2
*     INPUT LATTICE CONSTANTS.
*     ==> LATT A B C ALPHA BETA GAMMA
 
*         A,
*         B,
*         C: LATTICE CONSTANTS IN ANGSTROMS.
*     ALPHA,
*      BETA,
*     GAMMA: LATTICE CONSTANTS IN DEGREES.
 
*     INSTRUCTION 3
*     INPUT SYMMETRY OPERATIONS.
*     ==> SYMM XYZ
 
*     XYZ: SYMMETRY OPERATIONS EXPRESSED IN THE FORM OF A COORDINATE TRI
*          EXAMPLE: SYMM 1/2-X,-Y,1/2+Z.
 
*     INSTRUCTION 4
*     INPUT A SITE NAME AND STRUCTURAL PARAMETERS.
*     REPEAT THIS INSTRUCTION N TIMES (N: NUMBER OF ATOMS IN ASYMMETRIC
*     THERE ARE TWO KINDS OF FORMS:
*     ==> (SITE NAME) X Y Z B
*             OR
*     ==> (SITE NAME) X Y Z BETA11 BETA22 BETA33 BETA12 BETA13 BETA23
*     NO INSTRUCTION LABEL IS NEEDED.  THE MAXIMUM LENGTH OF SITE NAME I
*     EXAMPLE: CU(1) 0.0 0.0 0.3543 0.46.
 
*          X,
*          Y,
*          Z: FRACTIONAL COORDINATES.
*          B: INDIVIDUAL ISOTROPIC THERMAL PARAMETER IN ANGSTROMS**2.
*     BETA11,
*     BETA22,
*     BETA33,
*     BETA12,
*     BETA13,
*     BETA23: ANISOTROPIC THERMAL PARAMETERS WHEN THE ANISOTROPIC TEMPER
*             FACTOR, T(ANISO) IS DEFINED AS:
*               T(ANISO) = EXP(-(H**2*BETA11 + K**2*BETA22 + L**2*BETA33
*                          2*H*K*BETA12 + 2*H*L*BETA13 + 2*K*L*BETA23)).
 
*     INSTRUCTION 5  (101)
*     PRINT OUT A LIST OF INTERATOMIC DISTANCES.  THIS INSTRUCTION IS VE
*     USEFUL FOR EXAMINING THE COORDINATION NUMBER OF EACH ATOM.
*     ==> DMAX RADIUS
 
*     RADIUS: BOND DISTANCES (UNIT: ANGSTROM) SMALLER THAN THIS VALUE AR
*             PRINTED.
 
*     INSTRUCTION 6  (301)
*     SPECIFY THE DISTANCE FROM THE VISUAL POINT TO THE CENTER OF THE UN
*     ==> DIST R
 
*     R: DISTANCE IN CENTIMETERS FROM THE VISUAL POINT TO (1/2,1/2,1/2).
 
*     INSTRUCTIONS 7  (401)
*     ADD ATOMS TO BE PLOTTED FROM THE REGISTERED MEMBERS.
*     ==> ADDA ADC1 ADC2 .....
 
*     ADC(I): ATOMIC DISIGNATOR CODES (ADC) OR ATOMIC DESIGNATOR RUNS (A
 
*     NOTE]  IF YOU WANT TO KNOW ADC'S OF SOME ATOMS, SPECIFY A TRICLINI
*     ENCLOSING THEM, AND REFER TO A PRINTER OUTPUT FOR THE 'BALL' INSTR
*     IN THE OUTPUT, ADC, POSITION IN AN ORTEP DRAWING, AND FRACTIONAL C
*     NATES ARE LISTED.
 
*     INSTRUCTION 8  (404)
*     ADD ATOMS IN A BOX WITH SIX PLANES PARALLEL TO THE UNIT CELL.  ATO
*     REGISTERED WITH THIS INSTRUCTION ARE DRAWN IN SUCH A WAY AS SPECIF
*     THE 'BALL' INSTRUCTION.
*     ==> ABOX ANR1 ANR2 NCBOX ALIM BLIM CLIM
 
*      ANR1: STARTING VALUE OF ANR FOR ATOMS TO BE REGISTERED.
*      ANR2: LAST VALUE OF ANR FOR ATOMS TO BE REGISTERED.
*     NCBOX: SITE NUMBER OR ADC FOR THE CENTER OF AN ENCLOSURE BOX.
*            = 0, ORIGIN.
*            =-1, (1/2,1/2,1/2).
*      ALIM,
*      BLIM,
*      CLIM: ATOMS WHOSE FRACTIONAL COORDINATES ARE WITHIN THE RANGES, X
*            XC +/- ALIM, Y = YC +/- BLIM, AND Z = ZC +/- CLIM, ARE PLOT
*            (XC, YC, ZC) IS THE COORDINATE TRIPLET OF THE CENTER OF THE
*            ENCLOSURE BOX (DEFAULT: ALIM = BLIM = CLIM = 0.5, THAT IS,
*            IN A UNIT CELL ARE INCLUDED AS REGISTERED MEMBERS).
 
*     INSTRUCTION 9  (411)
*     ==> DELA ADC1 ADC2 .....
*     DELETE ATOMS FROM THE REGISTERED MEMBERS.
*     * ADC(I): ATOMIC DISIGNATOR CODES (ADC) OR ATOMIC DESIGNATOR RUNS
 
*     INSTRUCTION 10  (414)
*     DELETE ATOMS IN A BOX WITH SIX PLANES PARALLEL TO UNIT CELL.
*     ==> DBOX ANR1 ANR2 NCBOX ALIM BLIM CLIM
 
*      ANR1: STARTING VALUE OF ANR FOR ATOMS TO BE DELETED.
*      ANR2: FINAL VALUE OF ANR FOR ATOMS TO BE DELETED.
*     NCBOX: SITE NUMBER OR ADC FOR THE CENTER OF AN EXCLOSURE BOX.
*            = 0, ORIGIN.
*            =-1, (1/2,1/2,1/2).
*      ALIM,
*      BLIM,
*      CLIM: ATOMS WHOSE FRACTIONAL COORDINATES ARE WITHIN THE RANGES, X
*            XC +/- ALIM, Y = YC +/- BLIM, AND Z = ZC +/- CLIM, ARE DELE
*            (XC, YC, ZC) IS THE COORDINATE TRIPLET OF THE CENTER OF THE
*            ENCLOSURE BOX (DEFAULT: ALIM = BLIM = CLIM = 0.5, THAT IS,
*            IN A UNIT CELL ARE INCLUDED AS REGISTERED MEMBERS).
 
*     INSTRUCTION 11  (502)
*     ROTATE AXES BY DESIRED ANGLES.
*     ==> ROTA PHI1 PHI2 PHI3
 
*     PHI1: ROTATION ANGLES IN DEGREES ROUND THE X-AXIS.
*     PHI2: ROTATION ANGLES IN DEGREES ROUND THE Z-AXIS (NOT Y-AXIS).
*     PHI3: ROTATION ANGLES IN DEGREES ROUND THE Y-AXIS (NOT Z-AXIS).
 
*     WHEN THE A- AND B-AXES ARE REPRESENTED BY VECTORS U AND V, X-, Y-,
*     Z-AXES, RESPECTIVELY DEFINED AS U, U*V, AND U*(U*V), WHERE '*' DEN
*     THE VECTOR PRODUCT.
 
*     INSTRUCTION 12  (604)
*     INPUT THE SCALE OF THE TOTAL FIGURE AND DIMENSIONS OF THERMAL ELLI
*     ==> SCAL FACTOR PREL X0 Y0
 
*     FACTOR: OVERALL SCALE FACTOR (O FOR THE DEFAULT VALUE).
*       PREL: PROBABILITY CORRESPONDING TO THE DIMENSIONS OF THERMAL ELL
*             (DEFAULT: 85%).
*         X0,
*         Y0: THE ORIGIN IS POSITIONED AT THE LEFT BOTTOM OF THE FIGURE,
*             (1/2,1/2,1/2) IS LOCATED AT X0, Y0 (UNIT: CENTIMETER).
*             (X0=Y0=0 FOR DEFAULT VALUES).
 
*     INSTRUCTION 13  (705)
*     SPECIFY THE MANNER IN WHICH ATOMS ARE DRAWN.
*     ==> BALL NPLANE NLINE
 
*     NPLANE: = 1, BOUNDARY ELLIPSE ONLY.
*             = 4, BOUNDARY + PRINCIPAL ELLIPSES.
*      NLINE: = 0, NO FORWARD AXES OR SHADING.
*             = 1, FORWARD PRINCIPAL AXES ONLY.
*             = N, FORWARD AXES + (N-1) LINE SHADING.
 
*     INSTRUCTION 14  (801)
*     PLOT THE UNIT CELL.
*     ==> CELL
 
*     INSTRUCTION (15)  <801>
*     CONNECT A PAIR OF ATOMS SPECIFIED WITH ADC'S.
*     ==> PAIR RAD2 ADC1 ADC2 .....
 
*       RAD2: RADIUS OF BONDS IN ANGSTROMS.
*     ADC(I): ATOMIC DISIGNATOR CODES FOR PAIRS TO BE CONNECTED.
 
*     INSTRUCTION 16  (802)
*     PLOT BONDS BETWEEN ATOMS A AND B.
*     ==> BOND ANR1 ANR2 ANR3 ANR4 D1 D2 RAD1
 
*     ANR1: STARTING ANR FOR ATOM A.
*     ANR2: LAST ANR FOR ATOM A.
*     ANR3: STARTING ANR FOR ATOM B.
*     ANR4: LAST ANR FOR ATOM B.
*       D1: MINIMUM INTERATOMIC DISTANCE IN ANGSTROMS.
*       D2: MAXIMUM INTERATOMIC DISTANCE IN ANGSTROMS.
*     RAD1: RADIUS OF BONDS IN ANGSTROMS.
 
*     INSTRUCTION 17  (901)
*     PLOT SITE NAMES AT SPECIFIED POSITIONS.
*     ==> LABL ADC XMOVE YMOVE HEIGHT
 
*        ADC: ADC OF THE TARGET ATOM.
*      XMOVE,
*      YMOVE: DISTANCES (UNIT: CENTIMETER) BY WHICH THE CHEMICAL SYMBOL
*             MOVED.
*     HEIGHT: HEIGHT OF CHARACTERS IN CENTIMETERS.
 
************************************************************************
 
      PROGRAM PRETEP
*     MAIN PROGRAM
      PARAMETER (MAXATM=200,MAXPAR=10*MAXATM)
      INTEGER R(3,3,96),IBOND(4,10),NADC(50),IADC(30,50),LADD(10),
     &  IBOX(2,10),NCBOX(10),IADD(500),IDEL(500),ILABEL(500)
      REAL T(3,96),PARAM(10,MAXATM),ABC(6),ROTANG(3),D(2,10),RAD(10),
     &  RAD2(50),ALIM(3,10),SHIFT(2),HXY(3,100)
      CHARACTER TITLE*72,NAME(MAXATM)*6
 
*     DEFAULT MAXIMUM DISTANCE TO BE LISTED: 3.2 ANGSTROMS
*     DEFAULT POSITION OF THE EYE: INFINITY
*     DEFAULT PROBABLITY FOR THERMAL ELLIPSOIDS = 85%
      DATA R/864*0.0/, NAME/MAXATM*' '/, NBOND/0/, RADIUS/3.2/,
     &  ROTANG/3*0.0/, DIST/0.0/, PREL/85.0/, NBOX/0/, LCELL/0/,
     &  TITLE/' '/, NSYM/0/, NSITE/0/, PARAM/MAXPAR*0.0/, NADD/0/,
     &  IADD/500*0/, NDEL/0/, IDEL/500*0/, NLABEL/0/, NPLANE/1/,
     &  NLINE/0/, ABC/6*0.0/, NCALL/0/, IADC/1500*0/, SHIFT/2*0.0/
 
      OPEN(UNIT=5)
      REWIND 5
      OPEN(UNIT=2)
      REWIND 2
*     READ PRETEP INSTRUCTIONS
      CALL MACRO(RADIUS,DIST,ROTANG,NBOND,IBOND,D,RAD,NCALL,RAD2,NADC,
     &  IADC,NBOX,LADD,IBOX,NCBOX,ALIM,FACTOR,PREL,SHIFT,LCELL,TITLE,
     &  ABC,NSYM,R,T,NSITE,NAME,PARAM,NADD,IADD,NDEL,IDEL,NLABEL,
     &  ILABEL,HXY,NPLANE,NLINE)
      CLOSE(UNIT=5)
      CLOSE(UNIT=2,STATUS='DELETE')
 
      IF (TITLE .EQ. ' ' .OR. NSITE .EQ. 0 .OR. ABC(1) .EQ. 0.0 .OR.
     &   NSYM .EQ. 0) THEN
         OPEN(UNIT=1)
         REWIND 1
*        READ AN ORFFE FILE
         CALL RDFFE(TITLE,NSITE,R,T,NSYM,NAME,PARAM,ABC)
         CLOSE(UNIT=1)
      END IF
 
      OPEN(UNIT=3)
      REWIND 3
*     UNIT 3 SHOULD NOT BE CLOSED BECAUSE ORTEP II MAY BE RUN
*     CONTINUOUSLY AFTER PRETEP HAS ENDED
*     WRITE STRUCTURE DATA
      CALL WRCRYS(TITLE,NSITE,R,T,NSYM,NAME,PARAM,ABC,NORG,NCENTR)
 
*     WRITE ORTEP INSTRUCTIONS
      CALL INSTR(NSITE,NORG,NCENTR,RADIUS,DIST,ROTANG,NBOND,IBOND,D,RAD,
     &  NCALL,RAD2,NADC,IADC,NBOX,LADD,IBOX,NCBOX,ALIM,FACTOR,PREL,SHIFT
     &  ,LCELL,NADD,IADD,NDEL,IDEL,NLABEL,ILABEL,HXY,NAME,NPLANE,NLINE)
      END
 
************************************************************************
 
      SUBROUTINE MACRO(RADIUS,DIST,ROTANG,NBOND,IBOND,D,RAD,NCALL,RAD2,
     &  NADC,IADC,NBOX,LADD,IBOX,NCBOX,ALIM,FACTOR,PREL,SHIFT,LCELL,
     &  TITLE,ABC,NSYM,R,T,NSITE,NAME,PARAM,NADD,IADD,NDEL,IDEL,
     &  NLABEL,ILABEL,HXY,NPLANE,NLINE)
*     READ PRETEP INSTRUCTIONS AND DECODE THEM
 
*     NINST: TOTAL NUMBER OF AVAILABLE INSTRUCTIONS
      PARAMETER (MAXATM=200,NINST=16)
      INTEGER IBOND(4,10),NADC(50),IADC(30,50),LADD(10),IBOX(2,10),
     &  NCBOX(10),R(3,3,96),IADD(500),IDEL(500),ILABEL(500)
      REAL ROTANG(3),D(2,10),RAD(10),RAD2(50),ALIM(3,10),SHIFT(2),
     &  ABC(6),T(3,96),HXY(3,100),PARAM(10,MAXATM)
      CHARACTER INST(100)*4,TITLE*72,COORD*20,NAME(MAXATM)*6
 
      CALL CONVRT(INST,MLINE)
 
      DO 50 I=1,MLINE
         IF (INST(I) .EQ. 'TITL') THEN
            READ(2,'(A)') TITLE
         ELSE IF (INST(I) .EQ. 'LATT') THEN
            READ(2,*) ABC
         ELSE IF (INST(I) .EQ. 'SYMM') THEN
            NSYM=NSYM+1
            READ(2,'(A)') COORD
            CALL DECODE(COORD,R(1,1,NSYM),T(1,NSYM))
         ELSE IF (INST(I) .EQ. 'ATOM') THEN
            NSITE=NSITE+1
*           READ STRUCTURE PARAMETERS, SKIPPING OCCUPATION FACTORS
            READ(2,*) NAME(NSITE),(PARAM(J,NSITE),J=2,10)
*           CHECK THE VALUES OF FRACTIONAL COORDINATES
            IF (ABS(PARAM(2,NSITE)) .GT. 1.0 .OR. ABS(PARAM(3,NSITE))
     &      .GT. 1.0 .OR. ABS(PARAM(4,NSITE)) .GT. 1.0) THEN
               CALL JOBEND('FRACTIONAL COORDINATES OUT OF RANGE')
            END IF
         ELSE IF (INST(I) .EQ. 'DMAX') THEN
            READ(2,*) RADIUS
         ELSE IF (INST(I) .EQ. 'ROTA') THEN
            READ(2,*) ROTANG(1),ROTANG(3),ROTANG(2)
         ELSE IF (INST(I) .EQ. 'BOND') THEN
            NBOND=NBOND+1
            IF (NBOND .GT. 10) CALL JOBEND('TOO MANY BOND INSTRUCTIONS')
            READ(2,*) (IBOND(J,NBOND),J=1,4),(D(J,NBOND),J=1,2),
     &      RAD(NBOND)
         ELSE IF (INST(I) .EQ. 'PAIR') THEN
            CALL CONNCT(NCALL,RAD2,NADC,IADC)
         ELSE IF (INST(I) .EQ. 'ABOX' .OR. INST(I) .EQ. 'DBOX') THEN
            NBOX=NBOX+1
            IF (NBOX .GT. 10) THEN
               CALL JOBEND('TOO LARGE NUMBER OF ENCLOSURE BOXES')
            ELSE IF (INST(I) .EQ. 'ABOX') THEN
               LADD(NBOX)=404
            ELSE
               LADD(NBOX)=414
            END IF
            READ(2,*) (IBOX(J,NBOX),J=1,2),NCBOX(NBOX),
     &      (ALIM(J,NBOX),J=1,3)
         ELSE IF (INST(I) .EQ. 'ADDA') THEN
            CALL ADATOM(NADD,IADD)
         ELSE IF (INST(I) .EQ. 'DELA') THEN
            CALL ADATOM(NDEL,IDEL)
         ELSE IF (INST(I) .EQ. 'DIST') THEN
            READ(2,*) DIST
         ELSE IF (INST(I) .EQ. 'SCAL') THEN
            READ(2,*) FACTOR,PREL,SHIFT(1),SHIFT(2)
            IF (PREL .LT. 0.0 .OR. PREL .GT. 100) THEN
               CALL JOBEND('THE VALUE OF PREL OUT OF RANGE')
            END IF
         ELSE IF (INST(I) .EQ. 'CELL') THEN
*           SKIP A VACANT LINE
            READ(2,'()')
*           LCELL=0: NOT PLOTTED (DEFAULT); LCELL=1: PLOTTED
            LCELL=1
         ELSE IF (INST(I) .EQ. 'LABL') THEN
            NLABEL=NLABEL+1
            READ(2,*) ILABEL(NLABEL),HXY(2,NLABEL),HXY(3,NLABEL),
     &      HXY(1,NLABEL)
         ELSE IF (INST(I) .EQ. 'BALL') THEN
            READ(2,*) NPLANE,NLINE
            IF (NPLANE .LT. 0 .OR. NPLANE .GT. 4) THEN
               CALL JOBEND('BAD NPLANE VALUE')
            ELSE IF (NLINE .LT. 0) THEN
               CALL JOBEND('BAD NLINE VALUE')
            END IF
         END IF
   50 CONTINUE
      END
 
************************************************************************
 
      SUBROUTINE CONVRT(INST,MLINE)
*     MAKE A TEMPORARY FILE STORING PARAMETERS IN PRETEP INSTRUCTIONS
      PARAMETER (NINST=16)
      CHARACTER INST(100)*4,CHECK(NINST)*4,LINE*76,LINE2*80
      DATA CHECK/'TITL','LATT','SYMM','DMAX','ROTA','BOND','PAIR',
     &  'ABOX','DBOX','ADDA','DELA','DIST','SCAL','CELL','LABL','BALL'/
 
*     FILE #2 STORES PARAMETERS IN PRETEP INSTRUCTIONS.  '/' IS ADDED
*     TO THE TAIL OF EACH LINE.  THEN, WE CAN READ PARAMETERS FROM FILE
*     #2 WITH LIST-DIRECTED READ STATEMENTS.
 
      DO 15 I=1,100
         READ(5,'(2A)',END=3) INST(I),LINE
         DO 10 J=1,NINST
            IF (INST(I) .EQ. CHECK(J)) THEN
               WRITE(2,'(2A)') LINE(2:),'/'
               GO TO 15
            END IF
   10    CONTINUE
         LINE2=INST(I)//LINE
*        CLASSIFIED INTO 'ATOM' INSTRUCTION
         INST(I)='ATOM'
         ISPACE=INDEX(LINE2,' ')
         WRITE(2,'(5A)') '''',LINE2(:ISPACE-1),'''',LINE2(ISPACE:77),'/'
   15 CONTINUE
      CALL JOBEND('TOO MANY INSTRUCTIONS')
    3 MLINE=I-1
      REWIND 2
      END
 
************************************************************************
 
      SUBROUTINE DECODE(COORD,R,T)
*     CONVERT THREE CHARACTER DATA INTO A ROTATION MATRIX (R) AND
*     A TRANSLATION VECTOR (T)
      CHARACTER CHAR*1,COORD*20,XYZ(3)*1,SYM(3)*10
      INTEGER R(3,3),IX(3)
      REAL T(3)
      DATA XYZ/'X','Y','Z'/
 
      I1=INDEX(COORD,',')
      DO 10 J=I1+2,19
         READ(COORD(J:J),'(A)') CHAR
         IF (CHAR .EQ. ',') THEN
            I2=J
            GO TO 1
         END IF
   10 CONTINUE
    1 SYM(1)=COORD(1:I1-1)
      SYM(2)=COORD(I1+1:I2-1)
      SYM(3)=COORD(I2+1:20)
*
      DO 30 J=1,3
*
*        ROTATION MATRIX
         DO 25 JJ=1,3
            IX(JJ)=INDEX(SYM(J),XYZ(JJ))
            IF (IX(JJ) .GT. 0) THEN
               IF (IX(JJ) .EQ. 1 .OR. SYM(J)(IX(JJ)-1:IX(JJ)-1) .EQ.
     &         '+') THEN
                  R(J,JJ)=1
               ELSE
                  R(J,JJ)=-1
               END IF
            END IF
   25    CONTINUE
*
*        TRANSLATION VECTOR
         T(J)=0.0
         IT=INDEX(SYM(J),'/')
         IF (IT .GT. 0) THEN
            READ(SYM(J)(IT-1:IT-1),'(I1)') N1
            READ(SYM(J)(IT+1:IT+1),'(I1)') N2
            T(J)=FLOAT(N1)/FLOAT(N2)
            IF (IT .NE. 2 .AND. SYM(J)(IT-2:IT-2) .EQ. '-') T(J)=-T(J)
         END IF
   30 CONTINUE
      END
 
************************************************************************
 
      SUBROUTINE CONNCT(NCALL,RAD2,NADC,IADC)
*     SPECIFY THE RADIUS OF BONDS AND ATOMIC PAIRS TO BE CONNECTED
      INTEGER NADC(50),IADC(30,50)
      REAL RAD2(50)
 
      NCALL=NCALL+1
      READ(2,*) RAD2(NCALL),(IADC(J,NCALL),J=1,30)
      DO 30 J=1,50
         IF (IADC(J,NCALL) .EQ. 0) THEN
            NADC(NCALL)=J-1
            RETURN
         END IF
   30 CONTINUE
      NADC(NCALL)=50
      END
 
************************************************************************
 
      SUBROUTINE ADATOM(NAD,IAD)
*     SPECIFY ATOMS TO BE ADDED OR DELETED
      INTEGER NAD,IAD(500)
 
      READ(2,*) (IAD(J),J=NAD+1,500)
      DO 30 J=NAD+1,500
         IF (IAD(J) .EQ. 0) THEN
            NAD=J-1
            RETURN
         END IF
   30 CONTINUE
      NAD=500
      END
 
************************************************************************
 
      SUBROUTINE RDFFE(TITLE,NSITE,R,T,NSYM,NAME,PARAM,ABC)
*     READ AN ORFFE FILE
 
*     TITLE: TITLE
*     NSITE: NUMBER OF SITES
*         R: ROTATION MATRIXES
*         T: TRANSLATION VECTOR
*      NSYM: NUMBER OF SYMMETRY OPERATIONS
*      NAME: SITE NAMES
*     PARAM: STRUCTURE PARAMETERS
*       ABC: A, B, C, COS(ALPHA), COS(BETA), COS(GAMMA)
      PARAMETER (MAXATM=200)
      INTEGER R(3,3,96),ROR(2,3)
      REAL T(3,96),PARAM(10,MAXATM),ABC(6)
      CHARACTER TITLE*72,ATM*9,ATM2*9,NAME(MAXATM)*6,LINE*80
 
*     TITLE
      IF (TITLE .EQ. ' ') THEN
         READ(1,'(A)') TITLE
      ELSE
         READ(1,'()')
      END IF
 
*     SKIP LINEAR CONSTRAINTS
    1 CONTINUE
         READ(1,'(A)') LINE
      IF (LINE(1:6) .NE. 'ENDCON') GO TO 1
 
*     STRUCTURE PARAMETERS
      READ(1,*) MSITE
      IF (NSITE .EQ. 0) THEN
         NSITE=MSITE/10
         DO 25 I=1,NSITE
            READ(1,'(A,1X,10F14.0)') ATM,(PARAM(J,I),J=1,10)
            ATM2=' '
*           DELETE SPACES
            IP=1
            DO 15 J=1,9
               IF (ATM(J:J) .NE. ' ') THEN
                  ATM2(IP:IP)=ATM(J:J)
                  IP=IP+1
               END IF
   15       CONTINUE
            LENGTH=IP-1
            IF (LENGTH .LE. 6) THEN
               NAME(I)=ATM2
            ELSE
*              DELETE '(' AND ')'
               IP=1
               DO 20 J=1,LENGTH
                  IF (ATM2(J:J) .EQ. '(') THEN
                     NAME(I)(IP:IP)=' '
                     IP=IP+1
                  ELSE IF (ATM2(J:J) .NE. ')') THEN
                     NAME(I)(IP:IP)=ATM2(J:J)
                     IP=IP+1
                  END IF
                  IF (IP .GT. 6) GO TO 25
   20          CONTINUE
            END IF
   25    CONTINUE
      ELSE
         DO 30 I=1,MSITE/10
            READ(1,'()')
   30    CONTINUE
      END IF
 
*     SKIP REFINEMENT INDICATORS
      READ(1,'(150I1)') (ITEMP,I=1,NSITE*10)
*     SKIP A VARIANCE-COVARIANCE MATRIX
      READ(1,'(I5/(10F14.0))') NV,(RTEMP,I=1,NV*(NV+1)/2)
 
*     READ A, B, C, COS(ALPHA), COS(BETA), COS(GAMMA)
      IF (ABC(1) .EQ. 0.0) THEN
         READ(1,*) ABC
      ELSE
         READ(1,'()')
      END IF
      IF (NSYM .GT. 0) RETURN
 
*     SKIP STANDARD DEVIATIONS
      READ(1,'()')
 
*     MAKE SYMMETRY OPEARATION FOR (X, Y, Z)
      DO 50 J=1,3
         T(J,1)=0.0
         R(J,J,1)=1
   50 CONTINUE
*     SKIP A TRANSLATED POSITION, (1+X,1+Y,1+Z)
      READ(1,'()')
 
*     READ SYMMETRY OPERATIONS
      DO 80 I=2,96
         READ(1,'(A)') LINE
         IF (LINE(1:6) .EQ. 'ENDSYM') GO TO 9
         READ(LINE,'(3(F11.6,2I2))') (T(K,I),(ROR(L,K),L=1,2),K=1,3)
*        CONVERT ROR INTO A ROTATION MATRIX
         DO 75 J=1,3
            DO 70 K=1,3
               DO 65 L=1,2
                  IF (ROR(L,K) .EQ. J) THEN
                     R(K,J,I)=1
                  ELSE IF (ROR(L,K) .EQ. -J) THEN
                     R(K,J,I)=-1
                  END IF
   65          CONTINUE
   70       CONTINUE
   75    CONTINUE
*        SKIP A TRANSLATED POSITION
         READ(1,'()')
   80 CONTINUE
      WRITE(6,'(A/A)') ' TOO MANY SYMMETRY OPERATIONS (MAXIMUM: 96).',
     &' INPUT TITL, LATT, SYMM, AND STRUCTURE PARAMETERS BY YOURSELF.'
      STOP
    9 NSYM=I-1
      END
 
************************************************************************
 
      SUBROUTINE WRCRYS(TITLE,NSITE,R,T,NSYM,NAME,PARAM,ABC,NORG,NCENTR)
*     WRITE TITLE, SYMMETRY OPERATIONS, AND STRUCTURE PARAMETERS
      PARAMETER (MAXATM=200)
      INTEGER R(3,3,96)
      REAL T(3,96),PARAM(10,MAXATM),ABC(6)
      CHARACTER TITLE*72,NAME(MAXATM)*6
 
      WRITE(3,'(A)') TITLE
      WRITE(3,'(6F9.5)') ABC
      ITOP=0
      DO 20 I=1,NSYM
         IF (I .EQ. NSYM) ITOP=9
         WRITE(3,'(I1,F14.6,3I3,2(F15.6,3I3))')
     &   ITOP,(T(K,I),(R(K,J,I),J=1,3),K=1,3)
   20 CONTINUE
 
*     NORG: SITE NUMBER FOR THE ORIGIN
      NORG=0
*     NCENTR: SERIAL NUMBER FOR THE CENTER OF THE LATTICE
      DO 40 I=1,NSITE
*        SITE NUMBERS (I) ARE ADDED TO ORIGINAL INPUT DATA
         WRITE(3,'(A,I3,18X,3F9.5)') NAME(I),I,(PARAM(J,I),J=2,4)
         IF (NORG .EQ. 0 .AND. PARAM(2,I) .EQ. 0.0 .AND.
     &   PARAM(3,I) .EQ. 0.0 .AND. PARAM(4,I) .EQ. 0.0) THEN
            NORG=I
            NCENTR=NSITE+1
         END IF
         IF (PARAM(6,I) .EQ. 0.0 .AND. PARAM(7,I) .EQ. 0.0) THEN
*           ISOTROPIC THERMAL PARAMETER
            WRITE(3,'(F9.4)') PARAM(5,I)
         ELSE
*           ANISOTROPIC THERMAL PARAMETERS
            WRITE(3,'(6F9.6)') (PARAM(J,I),J=5,10)
         END IF
   40 CONTINUE
*     ORIGIN
      IF (NORG .EQ. 0) THEN
         NORG=NSITE+1
         NCENTR=NORG+1
         WRITE(3,'(A,I3,18X,3F9.5/F9.4)') 'ORIGIN',NORG,0.,0.,0.,.005
      END IF
*     CENTER OF THE UNIT CELL
      WRITE(3,'(A,I3,18X,3F9.5/I1)') 'CENTER',NCENTR,0.5,0.5,0.5,9
      END
 
************************************************************************
 
      SUBROUTINE INSTR(NSITE,NORG,NCENTR,RADIUS,DIST,ROTANG,NBOND,IBOND,
     &  D,RAD,NCALL,RAD2,NADC,IADC,NBOX,LADD,IBOX,NCBOX,ALIM,FACTOR,
     &  PREL,SHIFT,LCELL,NADD,IADD,NDEL,IDEL,NLABEL,ILABEL,HXY,NAME,
     &  NPLANE,NLINE)
*     WRITE ORTEP INSTRUCTIONS
      PARAMETER (MAXATM=200)
      INTEGER IBOND(4,10),NADC(50),IADC(30,50),LADD(10),IBOX(2,10),
     &  NCBOX(10),IADD(500),IDEL(500),ILABEL(500)
      REAL ROTANG(3),D(2,10),RAD(10),RAD2(50),ALIM(3,10),SHIFT(2),
     &  HXY(3,100)
      CHARACTER NAME(MAXATM)*6
 
      WRITE(3,'(I3,I6,4I9,F9.2)') 3,101,1,NSITE,1,NSITE,RADIUS
      WRITE(3,'(A,F5.2,A)') '*** LIST BOND DISTANCES SMALLER THAN',
     &  RADIUS,' ANGSTROMS ***'
 
      WRITE(3,'(I3,I6)') 3,201
      WRITE(3,'(A)') '*** INITIALIZE THE PLOT PACKAGE ***'
 
      WRITE(3,'(I3,I6,4F9.2)') 3,301,25.0,24.0,DIST,1.0
      WRITE(3,'(A)') '*** PLOT BOUNDARY ***'
 
      WRITE(3,'(I3,I6,F9.4)') 3,303,0.0
      WRITE(3,'(A)') '*** RETRACE DISPLACEMENT ***'
 
      CALL BOX(NORG,NCENTR,NSITE,NBOX,LADD,IBOX,NCBOX,ALIM,NADD)
 
      IF (NADD .GT. 0) CALL DELADD(NADD,IADD,401)
 
      IF (NDEL .GT. 0) CALL DELADD(NDEL,IDEL,411)
 
      IF (NORG .GT. NSITE .AND. LCELL .EQ. 1) THEN
*        SINCE THE ORIGIN IS VACANT, A VIRTUAL ATOM IS LOCATED
         WRITE(3,'(I3,I6,2(I4,I5))') 3,401,NORG,55501,NORG,66601
         WRITE(3,'(A)') '*** ADD THE ORIGIN TO THE BOX OF ENCLOSURE ***'
      END IF
 
      WRITE(3,'(I3,I6,I4,I5,4I9,17X,I1)') 3,501,NCENTR,55501,
     &  155501,165501,155501,156501,0
      WRITE(3,'(A)') '*** ASSIGN THE REFERENCE CARTESIAN SYSTEM ***'
 
      WRITE(3,'(I3,I6,3(I9,F9.2))') 3,502,(I,ROTANG(I),I=1,3)
      WRITE(3,'(A)') '*** ROTATE THE REFERENCE CARTESIAN SYSTEM ***'
 
      CALL SCAL(FACTOR,PREL,SHIFT)
 
      CALL BONDS(NBOND,IBOND,D,RAD,LCELL,NORG,1)
 
      IF (NCALL .GT. 0) CALL PAIR(NCALL,RAD2,NADC,IADC,1)
 
      WRITE(3,'(I3,I6,4I9)') 1,705,NPLANE,0,NLINE,0
*     MAX(NSITE,NORG): NUMBER OF SITES INCLUDING THE (VIRTUAL) ORIGIN
      WRITE(3,'(I3,24X,2I9)') 3,1,MAX(NSITE,NORG)
      WRITE(3,'(A)') '*** ATOM PLOTTING CONDITIONS ***'
 
      IF (LCELL .EQ. 1) CALL AXES(NORG)
 
      IF (NBOND .NE. 0) CALL BONDS(NBOND,IBOND,D,RAD,LCELL,NORG,2)
 
      IF (NCALL .NE. 0) CALL PAIR(NCALL,RAD2,NADC,IADC,2)
 
      IF (NLABEL .GT. 0) CALL LABEL(NLABEL,ILABEL,NAME,HXY)
 
      WRITE(3,'(I3,I6)') 3,-1
      WRITE(3,'(A)') '*** END OF JOB ***'
      END
 
************************************************************************
 
      SUBROUTINE BOX(NORG,NCENTR,NSITE,NBOX,LADD,IBOX,NCBOX,ALIM,NADD)
*     SPECIFY BOX OF ENCLOSURE
      INTEGER LADD(10),IBOX(2,10),NCBOX(10)
      REAL ALIM(3,10)
 
      IF (NBOX .EQ. 0 .AND. NADD .EQ. 0) THEN
*        DEFAULT BOX = UNIT CELL
         WRITE(3,'(I3,I6,I4,I5,3I9,3F9.4)') 3,404,NCENTR,55501,NCENTR,
     &   1,NSITE,0.5,0.5,0.5
         WRITE(3,'(A)') '*** BOX OF ENCLOSURE: UNIT CELL ***'
      ELSE
         DO 30 I=1,NBOX
            IF (NCBOX(I) .GT. 100000) THEN
*              ADC
               NN=NCBOX(I)
            ELSE IF (NCBOX(I) .EQ. 0) THEN
*              ORIGIN
               NN=NORG*100000+55501
            ELSE IF (NCBOX(I) .EQ. -1) THEN
*              (1/2,1/2,1/2)
               NN=NCENTR*100000+55501
            ELSE IF (NCBOX(I) .GE. 1 .AND. NCBOX(I) .LE. NSITE) THEN
*              SITE NUMBER
               NN=NCBOX(I)*100000+55501
            ELSE
               WRITE(6,'(A,I6)') ' BAD NCBOX VALUE: ',NCBOX(I)
               STOP
            END IF
            WRITE(3,'(I3,I6,4I9,3F9.4)')
     &      3,LADD(I),NN,NN,(IBOX(J,I),J=1,2),(ALIM(J,I),J=1,3)
            IF (LADD(I) .EQ. 404) THEN
               WRITE(3,'(2(A,I2),A)') '*** ADD ATOMS #',IBOX(1,I),' -',
     &         IBOX(2,I),' IN A TRICLINIC BOX ***'
            ELSE
               WRITE(3,'(2(A,I2),A)') '*** SUBTRACT ATOMS #',IBOX(1,I),
     &         ' -',IBOX(2,I),' IN A TRICLINIC BOX'
            END IF
   30    CONTINUE
      END IF
      END
 
************************************************************************
 
      SUBROUTINE DELADD(NDA,IDA,NOINST)
*     WRITE A 401 OR 411 INSTRUCTION
      INTEGER IDA(500)
 
      DO 40 I=1,NDA,7
         IF (I+6 .GE. NDA) THEN
            WRITE(3,'(I3,I6,7I9)') 3,NOINST,(IDA(J),J=I,NDA)
         ELSE
            WRITE(3,'(I3,I6,7I9)') 1,NOINST,(IDA(J),J=I,I+6)
         END IF
   40 CONTINUE
      IF (NOINST .EQ. 401) THEN
         WRITE(3,'(A)') '*** ADD ATOMS TO BE PLOTTED ***'
      ELSE
         WRITE(3,'(A)') '*** DELETE ATOMS FROM THE REGISTERED MEMBERS'//
     &   ' ***'
      END IF
      END
 
************************************************************************
 
      SUBROUTINE SCAL(FACTOR,PREL,SHIFT)
*     DETERMINE THE CRITICAL VALUE FOR PROBABILITY ELLIPSOIDS
      REAL SHIFT(2),P(120),C(120)
      DATA P/0.01, 0.02, 0.03, 0.04, 0.05, 0.06, 0.07, 0.08, 0.09, 0.10,
     & 0.11, 0.12, 0.13, 0.14, 0.15, 0.16, 0.17, 0.18, 0.19, 0.20, 0.21,
     & 0.22, 0.23, 0.24, 0.25, 0.26, 0.27, 0.28, 0.29, 0.30, 0.31, 0.32,
     & 0.33, 0.34, 0.35, 0.36, 0.37, 0.38, 0.39, 0.40, 0.41, 0.42, 0.43,
     & 0.44, 0.45, 0.46, 0.47, 0.48, 0.49, 0.50, 0.51, 0.52, 0.53, 0.54,
     & 0.55, 0.56, 0.57, 0.58, 0.59, 0.60, 0.61, 0.62, 0.63, 0.64, 0.65,
     & 0.66, 0.67, 0.68, 0.69, 0.70, 0.71, 0.72, 0.73, 0.74, 0.75, 0.76,
     & 0.77, 0.78, 0.79, 0.80, 0.81, 0.82, 0.83, 0.84, 0.85, 0.86, 0.87,
     & 0.88, 0.89, 0.90, 0.91, 0.92, 0.93, 0.94, 0.95, 0.96, 0.97, 0.98,
     & 0.99, 0.991, 0.992, 0.993, 0.994, 0.995, 0.996, 0.997, 0.998,
     & 0.999, 0.9991, 0.9992, 0.9993, 0.9994, 0.9995, 0.9996, 0.9997,
     & 0.9998, 0.9999, 0.99999, 0.999999, 0.9999999/
      DATA C/
     & 0.3389, 0.4299, 0.4951, 0.5479, 0.5932, 0.6334, 0.6699, 0.7035,
     & 0.7349, 0.7644, 0.7924, 0.8192, 0.8447, 0.8694, 0.8932, 0.9162,
     & 0.9386, 0.9605, 0.9818, 1.0026, 1.0230, 1.0430, 1.0627, 1.0821,
     & 1.1012, 1.1200, 1.1386, 1.1570, 1.1751, 1.1932, 1.2110, 1.2288,
     & 1.2464, 1.2638, 1.2812, 1.2985, 1.3158, 1.3330, 1.3501, 1.3672,
     & 1.3842, 1.4013, 1.4183, 1.4354, 1.4524, 1.4695, 1.4866, 1.5037,
     & 1.5209, 1.5382, 1.5555, 1.5729, 1.5904, 1.6080, 1.6257, 1.6436,
     & 1.6616, 1.6797, 1.6980, 1.7164, 1.7351, 1.7540, 1.7730, 1.7924,
     & 1.8119, 1.8318, 1.8519, 1.8724, 1.8932, 1.9144, 1.9360, 1.9580,
     & 1.9804, 2.0034, 2.0269, 2.0510, 2.0757, 2.1012, 2.1274, 2.1544,
     & 2.1824, 2.2114, 2.2416, 2.2730, 2.3059, 2.3404, 2.3767, 2.4153,
     & 2.4563, 2.5003, 2.5478, 2.5997, 2.6571, 2.7216, 2.7955, 2.8829,
     & 2.9912, 3.1365, 3.3682, 3.4019, 3.4390, 3.4806, 3.5280, 2.5830,
     & 3.6492, 3.7325, 3.8465, 4.0331, 4.0607, 4.0912, 4.1256, 4.1648,
     & 4.2107, 4.2661, 4.3365, 4.4335, 5.5943, 5.0894, 5.5376, 5.9503/
 
      NTERMS=2
      CALL INTERP(P,C,120,NTERMS,PREL*0.01,PREL2)
      IF (FACTOR .EQ. 0.0 .AND. SHIFT(1) .EQ. 0.0 .AND. SHIFT(2) .EQ.
     &   0.0) THEN
         WRITE(3,'(I3,I6,27X,F9.3)') 3,604,PREL2
      ELSE IF (SHIFT(1) .EQ. 0.0 .AND. SHIFT(2) .EQ. 0.0) THEN
         WRITE(3,'(I3,I6,18X,2F9.3)') 3,603,FACTOR,PREL2
      ELSE IF (FACTOR .EQ. 0.0) THEN
         WRITE(3,'(I3,I6,2F9.2,9X,F9.3)') 3,602,SHIFT(1),SHIFT(2),PREL2
      ELSE
         WRITE(3,'(I3,I6,2F9.2,2F9.3)') 3,601,SHIFT(1),SHIFT(2),FACTOR,
     &   PREL2
      END IF
      WRITE(3,'(A)') '*** POSITIONING AND SCALING ***'
      END
 
************************************************************************
 
      SUBROUTINE INTERP(X,Y,NPTS,NTERMS,XIN,YOUT)
*     INTERPOLATE BETWEEN DATA POINTS TO EVALUATE A FUNCTION
      REAL X(*),Y(*),DELTA(10),A(10)
 
   11 DO 19 I=1,NPTS
      IF(XIN-X(I)) 13,17,19
   13 I1=I-NTERMS/2
      IF(I1) 15,15,21
   15 I1=1
      GO TO 21
   17 YOUT=Y(I)
   18 GO TO 61
   19 CONTINUE
      I1=NPTS-NTERMS+1
   21 I2=I1+NTERMS-1
      IF(NPTS-I2) 23,31,31
   23 I2=NPTS
      I1=I2-NTERMS+1
   25 IF(I1) 26,26,31
   26 I1=1
   27 NTERMS=I2-I1+1
   31 DENOM=X(I1+1)-X(I1)
      DELTAX=(XIN-X(I1))/DENOM
      DO 35 I=1,NTERMS
      IX=I1+I-1
   35 DELTA(I)=(X(IX)-X(I1))/DENOM
   40 A(1)=Y(I1)
   41 DO 50 K=2,NTERMS
      PROD=1.0
      SUM=0.0
      IMAX=K-1
      IXMAX=I1+IMAX
      DO 49 I=1,IMAX
      J=K-I
      PROD=PROD*(DELTA(K)-DELTA(J))
   49 SUM=SUM-A(J)/PROD
   50 A(K)=SUM+Y(IXMAX)/PROD
   51 SUM=A(1)
      DO 57 J=2,NTERMS
      PROD=1.
      IMAX=J-1
      DO 56 I=1,IMAX
   56 PROD=PROD*(DELTAX-DELTA(I))
   57 SUM=SUM+A(J)*PROD
   60 YOUT=SUM
   61 END
 
************************************************************************
 
      SUBROUTINE BONDS(NBOND,IBOND,D,RAD,LCELL,NORG,IFLAG)
*     SPECIFIES BONDS TO BE ERASED (LFLAG=1) OR PLOTTED (LFLAG=2)
      INTEGER IORG(24),NBOND,IBOND(4,10)
*     D(1,I): D(MIN); D(2,I): D(MAX)
      REAL D(2,10),RAD(10)
      DATA IORG/555,655,555,565,555,556,556,656,556,566,666,566,666,656,
     &  665,565,665,655,665,666,656,655,566,565/
      IAT2(J)=NORG*100000+IORG(J)*100+1
 
      IF (IFLAG .EQ. 1) THEN
         WRITE(3,'(I3,I6)') 2,511
         IF (LCELL .EQ. 1) THEN
            WRITE(3,'(I3,6X,6I9)') 1,(IAT2(J),J=1,6),1,(IAT2(J),J=7,12),
     &      1,(IAT2(J),J=13,18),2,(IAT2(J),J=19,24)
            IF (NBOND .NE. 0) THEN
               WRITE(3,'(I3,18X,I3,12X,F6.3)') 2,1,0.001
            ELSE
               WRITE(3,'(I3,18X,I3,12X,F6.3)') 3,1,0.001
               WRITE(3,'(A)') '*** ERASE OVERLAPPING AXES ***'
               RETURN
            END IF
         END IF
      ELSE
         WRITE(3,'(I3,I6)') 2,802
      END IF
 
      LOOK=2
      DO 30 I=1,NBOND
         IF (I .EQ. NBOND) LOOK=3
         WRITE(3,'(I3,6X,5I3,3F6.3)') LOOK,(IBOND(J,I),J=1,4),5,
     &   (D(J,I),J=1,2),RAD(I)
   30 CONTINUE
 
      IF (IFLAG .EQ. 1) THEN
         WRITE(3,'(A)') '*** ERASE OVERLAPPING AXES AND BONDS ***'
      ELSE
         WRITE(3,'(A)') '*** PLOT SPECIFIED BONDS ***'
      END IF
      END
 
************************************************************************
 
      SUBROUTINE PAIR(NCALL,RAD2,NADC,IADC,IFLAG)
*     SPECIFIES BONDS PAIRS TO BE ERASED (LFLAG=1) OR PLOTTED (LFLAG=2)
      INTEGER NADC(50),IADC(30,50)
      REAL RAD2(50)
 
      DO 60 I=1,NCALL
         IF (IFLAG .EQ. 1) WRITE(3,'(I3,I6)') 2,511
 
         IF (6 .GE. NADC(I)) THEN
            WRITE(3,'(I3,I6,6I9)') 2,801,(IADC(K,I),K=1,NADC(I))
         ELSE
            WRITE(3,'(I3,I6,6I9)') 1,801,(IADC(K,I),K=1,6)
         END IF
         DO 40 J=7,NADC(I),6
            IF (J+5 .GE. NADC(I)) THEN
               WRITE(3,'(I3,6X,6I9)') 2,(IADC(K,I),K=J,NADC(I))
            ELSE
               WRITE(3,'(I3,6X,6I9)') 1,(IADC(K,I),K=J,J+5)
            END IF
   40    CONTINUE
         WRITE(3,'(I3,18X,I3,12X,F6.3)') 3,5,RAD2(I)
 
         IF (IFLAG .EQ. 1) THEN
            WRITE(3,'(A)') '*** ERASE OVERLAPPING BONDS ***'
         ELSE
            WRITE(3,'(A)') '*** PLOT BONDS FOR SPECIFIED PAIRS ***'
         END IF
   60 CONTINUE
      END
 
************************************************************************
 
      SUBROUTINE LABEL(NLABEL,ILABEL,NAME,HXY)
*     PUT A LABEL TO AN ATOM
      PARAMETER (MAXATM=200)
      INTEGER ILABEL(500)
      REAL HXY(3,100)
      CHARACTER NAME(MAXATM)*6
 
      DO 80 I=1,NLABEL
         WRITE(3,'(I3,I6,I9,27X,3F9.3)') 3,901,ILABEL(I),
     &   (HXY(J,I),J=1,3)
         ISPACE=INDEX(NAME(ILABEL(I)/100000),' ')
         IF (ISPACE .EQ. 0) ISPACE=7
         WRITE(3,'(3A)') '*** WRITE ',
     &   NAME(ILABEL(I)/100000)(1:ISPACE-1),' ***'
   80 CONTINUE
      END
 
************************************************************************
 
      SUBROUTINE AXES(NORG)
*     PLOT A, B, AND C-AXES
      INTEGER IORG(24)
      DATA IORG/555,655,555,565,555,556,556,656,556,566,666,566,666,656,
     &  665,565,665,655,665,666,656,655,566,565/
      IAT2(J)=NORG*100000+IORG(J)*100+1
 
      WRITE(3,'(I3,I6,6I9)') 1,801,(IAT2(J),J=1,6)
      WRITE(3,'(I3,6X,6I9)') 1,(IAT2(J),J=7,12),1,(IAT2(J),J=13,18),
     &  2,(IAT2(J),J=19,24)
      WRITE(3,'(I3,18X,I3,12X,F6.3)') 3,1,0.001
      WRITE(3,'(A)') '*** PLOT A, B, AND C AXES ***'
      END
 
************************************************************************
 
      SUBROUTINE JOBEND(ERROR)
*     WRITE AN ERROR MESSAGE AND STOP THE JOB
      CHARACTER*(*) ERROR
 
      WRITE(6,'(2A)') ' ',ERROR
      STOP
      END
 
